Quickstart — Flask Dance 6.0.0 documentation

# Quickstart

The fastest way to get up and running with Flask-Dance is to start from an example project. First, decide which token storage you want to use:

- `SessionStorage` is the default because it requires zero configuration. It uses the Flask session to store OAuth tokens. It’s the easiest for getting started, but it’s not a good choice for production applications.

- `SQLAlchemyStorage` uses a relational database to store OAuth tokens. It’s great for production usage, but it requires a relational database with SQLAlchemy and it’s more complicated to set up.

If you’re not sure which to pick, start with `SessionStorage`. You can switch later, if you want.

Next, check the lists below to find the OAuth provider you’re interested in and jump to an example project that uses Flask-Dance with that provider!

## Flask sessions (easiest)

- GitHub

- Google

- Facebook

- Slack

- Twitter

- LinkedIn

- Heroku

- Fitbit

## SQLAlchemy

- Google

- Google with Flask-Security

- Twitter

- Facebook

- Heroku

- Multiple providers simultaneously

Other Providers

Don’t see the OAuth provider you want? Flask-Dance provides built-in support for even more providers, and you can configure Flask-Dance to support any custom provider you want. Start with any of the example projects listed above, and modify it to use the provider you want!

Fork me on GitHub